@@ -19,7 +19,7 @@
 
 /*
  * Author:  G. Jungman
- * RCS:     $Id: gsl_blas.h,v 1.15 2000/05/04 11:25:01 bjg Exp $
+ * RCS:     $Id: gsl_blas.h,v 1.19 2001/04/16 11:38:54 bjg Exp $
  */
 #ifndef __GSL_BLAS_H__
 #define __GSL_BLAS_H__
@@ -129,7 +129,7 @@ int  gsl_blas_cswap (gsl_vector_complex_float * X,
 int  gsl_blas_ccopy (const gsl_vector_complex_float * X,
                      gsl_vector_complex_float * Y);
 
-int  gsl_blas_caxpy (const gsl_complex_float * alpha,
+int  gsl_blas_caxpy (const gsl_complex_float alpha,
                      const gsl_vector_complex_float * X,
                      gsl_vector_complex_float * Y);
 
@@ -139,7 +139,7 @@ int  gsl_blas_zswap (gsl_vector_complex * X,
 int  gsl_blas_zcopy (const gsl_vector_complex * X,
                      gsl_vector_complex * Y);
 
-int  gsl_blas_zaxpy (const gsl_complex * alpha,
+int  gsl_blas_zaxpy (const gsl_complex alpha,
                      const gsl_vector_complex * X,
                      gsl_vector_complex * Y);
 
@@ -172,8 +172,8 @@ int  gsl_blas_drotm (gsl_vector * X,
 
 void gsl_blas_sscal  (float  alpha, gsl_vector_float * X);
 void gsl_blas_dscal  (double alpha, gsl_vector * X);
-void gsl_blas_cscal  (const gsl_complex_float * alpha, gsl_vector_complex_float * X);
-void gsl_blas_zscal  (const gsl_complex * alpha, gsl_vector_complex * X);
+void gsl_blas_cscal  (const gsl_complex_float alpha, gsl_vector_complex_float * X);
+void gsl_blas_zscal  (const gsl_complex alpha, gsl_vector_complex * X);
 void gsl_blas_csscal (float  alpha, gsl_vector_complex_float * X);
 void gsl_blas_zdscal (double alpha, gsl_vector_complex * X);
 
@@ -193,46 +193,16 @@ int  gsl_blas_sgemv (CBLAS_TRANSPOSE_t TransA,
                      float beta,
                      gsl_vector_float * Y);
 
-int  gsl_blas_sgbmv (CBLAS_TRANSPOSE_t TransA,
-                     int KL, int KU,
-		     float alpha,
-                     const gsl_matrix_float * A,
-                     const gsl_vector_float * X,
-                     float beta,
-                     gsl_vector_float * Y);
-
 int  gsl_blas_strmv (CBLAS_UPLO_t Uplo,
                      CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
                      const gsl_matrix_float * A,
                      gsl_vector_float * X);
 
-int  gsl_blas_stbmv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     int K,
-                     const gsl_matrix_float * A,
-                     gsl_vector_float * X);
-
-int  gsl_blas_stpmv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     const float Ap[],
-                     gsl_vector_float * X);
-
 int  gsl_blas_strsv (CBLAS_UPLO_t Uplo,
                      CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
                      const gsl_matrix_float * A,
                      gsl_vector_float * X);
 
-int  gsl_blas_stbsv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     int K,
-                     const gsl_matrix_float * A,
-                     gsl_vector_float * X);
-
-int  gsl_blas_stpsv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     const float Ap[],
-                     gsl_vector_float * X);
-
 int  gsl_blas_dgemv (CBLAS_TRANSPOSE_t TransA,
                      double alpha,
                      const gsl_matrix * A,
@@ -240,59 +210,21 @@ int  gsl_blas_dgemv (CBLAS_TRANSPOSE_t TransA,
                      double beta,
                      gsl_vector * Y);
 
-int  gsl_blas_dgbmv (CBLAS_TRANSPOSE_t TransA,
-                     int KL, int KU,
-                     double alpha,
-                     const gsl_matrix * A,
-                     const gsl_vector * X,
-                     double beta,
-                     gsl_vector * Y);
-
 int  gsl_blas_dtrmv (CBLAS_UPLO_t Uplo,
                      CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
                      const gsl_matrix * A,
                      gsl_vector * X);
 
-int  gsl_blas_dtbmv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     int K,
-                     const gsl_matrix * A,
-                     gsl_vector * X);
-
-int  gsl_blas_dtpmv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     const double Ap[],
-                     gsl_vector * X);
-
 int  gsl_blas_dtrsv (CBLAS_UPLO_t Uplo,
                      CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
                      const gsl_matrix * A,
                      gsl_vector * X);
 
-int  gsl_blas_dtbsv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     int K,
-                     const gsl_matrix * A,
-                     gsl_vector * X);
-
-int  gsl_blas_dtpsv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     const double Ap[],
-                     gsl_vector * X);
-
 int  gsl_blas_cgemv (CBLAS_TRANSPOSE_t TransA,
-                     const gsl_complex_float * alpha,
+                     const gsl_complex_float alpha,
                      const gsl_matrix_complex_float * A,
                      const gsl_vector_complex_float * X,
-                     const gsl_complex_float * beta,
-                     gsl_vector_complex_float * Y);
-
-int  gsl_blas_cgbmv (CBLAS_TRANSPOSE_t TransA,
-                     int KL, int KU,
-                     const gsl_complex_float * alpha,
-                     const gsl_matrix_complex_float * A,
-                     const gsl_vector_complex_float * X,
-                     const gsl_complex_float * beta,
+                     const gsl_complex_float beta,
                      gsl_vector_complex_float * Y);
 
 int  gsl_blas_ctrmv (CBLAS_UPLO_t Uplo,
@@ -300,46 +232,16 @@ int  gsl_blas_ctrmv (CBLAS_UPLO_t Uplo,
                      const gsl_matrix_complex_float * A,
                      gsl_vector_complex_float * X);
 
-int  gsl_blas_ctbmv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     int K,
-                     const gsl_matrix_complex_float * A,
-                     gsl_vector_complex_float * X);
-
-int  gsl_blas_ctpmv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     const void * Ap,
-                     gsl_vector_complex_float * X);
-
 int  gsl_blas_ctrsv (CBLAS_UPLO_t Uplo,
                      CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
                      const gsl_matrix_complex_float * A,
                      gsl_vector_complex_float * X);
 
-int  gsl_blas_ctbsv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     int K,
-                     const gsl_matrix_complex_float * A,
-                     gsl_vector_complex_float * X);
-
-int  gsl_blas_ctpsv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     const void * Ap,
-                     gsl_vector_complex_float * X);
-
 int  gsl_blas_zgemv (CBLAS_TRANSPOSE_t TransA,
-                     const gsl_complex * alpha,
+                     const gsl_complex alpha,
                      const gsl_matrix_complex * A,
                      const gsl_vector_complex * X,
-                     const gsl_complex * beta,
-                     gsl_vector_complex * Y);
-
-int  gsl_blas_zgbmv (CBLAS_TRANSPOSE_t TransA,
-                     int KL, int KU,
-                     const gsl_complex * alpha,
-                     const gsl_matrix_complex * A,
-                     const gsl_vector_complex * X,
-                     const gsl_complex * beta,
+                     const gsl_complex beta,
                      gsl_vector_complex * Y);
 
 int  gsl_blas_ztrmv (CBLAS_UPLO_t Uplo,
@@ -347,33 +249,11 @@ int  gsl_blas_ztrmv (CBLAS_UPLO_t Uplo,
                      const gsl_matrix_complex * A,
                      gsl_vector_complex * X);
 
-int  gsl_blas_ztbmv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     int K,
-                     const gsl_matrix_complex * A,
-                     gsl_vector_complex * X);
-
-int  gsl_blas_ztpmv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     const void *Ap,
-                     gsl_vector_complex * X);
-
 int  gsl_blas_ztrsv (CBLAS_UPLO_t Uplo,
                      CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
                      const gsl_matrix_complex * A,
                      gsl_vector_complex *X);
 
-int  gsl_blas_ztbsv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     int K,
-                     const gsl_matrix_complex * A,
-                     gsl_vector_complex * X);
-
-int  gsl_blas_ztpsv (CBLAS_UPLO_t Uplo,
-                     CBLAS_TRANSPOSE_t TransA, CBLAS_DIAG_t Diag,
-                     const void *Ap,
-                     gsl_vector_complex * X);
-
 /*
  * Routines with S and D prefixes only
  */
@@ -384,21 +264,6 @@ int  gsl_blas_ssymv (CBLAS_UPLO_t Uplo,
                      float beta,
                      gsl_vector_float * Y);
 
-int  gsl_blas_ssbmv (CBLAS_UPLO_t Uplo,
-                     int K,
-                     float alpha,
-                     const gsl_matrix_float * A,
-                     const gsl_vector_float * X,
-                     float beta,
-                     gsl_vector_float * Y);
-
-int  gsl_blas_sspmv (CBLAS_UPLO_t Uplo,
-                     float alpha,
-                     const float Ap[],
-                     const gsl_vector_float * X,
-                     float beta,
-                     gsl_vector_float * Y);
-
 int  gsl_blas_sger (float alpha,
                     const gsl_vector_float * X,
                     const gsl_vector_float * Y,
@@ -409,45 +274,18 @@ int  gsl_blas_ssyr (CBLAS_UPLO_t Uplo,
                     const gsl_vector_float * X,
                     gsl_matrix_float * A);
 
-int  gsl_blas_sspr (CBLAS_UPLO_t Uplo,
-                    float alpha,
-                    const gsl_vector_float * X,
-                    float Ap[]);
-
 int  gsl_blas_ssyr2 (CBLAS_UPLO_t Uplo,
                      float alpha,
                      const gsl_vector_float * X,
                      const gsl_vector_float * Y,
                      gsl_matrix_float * A);
 
-int  gsl_blas_sspr2 (CBLAS_UPLO_t Uplo,
-                     float alpha,
-                     const gsl_vector_float * X,
-                     const gsl_vector_float * Y,
-                     float * A);
-
 int  gsl_blas_dsymv (CBLAS_UPLO_t Uplo,
                      double alpha,
                      const gsl_matrix * A,
                      const gsl_vector * X,
                      double beta,
                      gsl_vector * Y);
-
-int  gsl_blas_dsbmv (CBLAS_UPLO_t Uplo,
-                     int K,
-                     double alpha,
-                     const gsl_matrix * A,
-                     const gsl_vector * X,
-                     double beta,
-                     gsl_vector * Y);
-
-int  gsl_blas_dspmv (CBLAS_UPLO_t Uplo,
-                     double alpha,
-                     const double Ap[],
-                     const gsl_vector * X,
-                     double beta,
-                     gsl_vector * Y);
-
 int  gsl_blas_dger (double alpha,
                     const gsl_vector * X,
                     const gsl_vector * Y,
@@ -458,54 +296,29 @@ int  gsl_blas_dsyr (CBLAS_UPLO_t Uplo,
                     const gsl_vector * X,
                     gsl_matrix * A);
 
-int  gsl_blas_dspr (CBLAS_UPLO_t Uplo,
-                    double alpha,
-                    const gsl_vector * X,
-                    double Ap[]);
-
 int  gsl_blas_dsyr2 (CBLAS_UPLO_t Uplo,
                      double alpha,
                      const gsl_vector * X,
                      const gsl_vector * Y,
                      gsl_matrix * A);
 
-int  gsl_blas_dspr2 (CBLAS_UPLO_t Uplo,
-                     double alpha,
-                     const gsl_vector * X,
-                     const gsl_vector * Y,
-                     double * Ap);
-
 /*
  * Routines with C and Z prefixes only
  */
+
 int  gsl_blas_chemv (CBLAS_UPLO_t Uplo,
-                     const gsl_complex_float * alpha,
+                     const gsl_complex_float alpha,
                      const gsl_matrix_complex_float * A,
                      const gsl_vector_complex_float * X,
-                     const gsl_complex_float * beta,
+                     const gsl_complex_float beta,
                      gsl_vector_complex_float * Y);
 
-int  gsl_blas_chbmv (CBLAS_UPLO_t Uplo,
-                     int K,
-                     const gsl_complex_float * alpha,
-                     const gsl_matrix_complex_float * A,
-                     const gsl_vector_complex_float * X,
-                     const gsl_complex_float * beta,
-                     gsl_vector_complex_float * Y);
-
-int  gsl_blas_chpmv (CBLAS_UPLO_t Uplo,
-                     const gsl_complex_float * alpha,
-		     const void * Ap,
-                     const gsl_vector_complex_float * X,
-                     const gsl_complex_float * beta,
-                     gsl_vector_complex_float * Y);
-
-int  gsl_blas_cgeru (const gsl_complex_float * alpha,
+int  gsl_blas_cgeru (const gsl_complex_float alpha,
                      const gsl_vector_complex_float * X,
                      const gsl_vector_complex_float * Y,
                      gsl_matrix_complex_float * A);
 
-int  gsl_blas_cgerc (const gsl_complex_float * alpha,
+int  gsl_blas_cgerc (const gsl_complex_float alpha,
                      const gsl_vector_complex_float * X,
                      const gsl_vector_complex_float * Y,
                      gsl_matrix_complex_float * A);
@@ -515,51 +328,25 @@ int  gsl_blas_cher (CBLAS_UPLO_t Uplo,
                     const gsl_vector_complex_float * X,
                     gsl_matrix_complex_float * A);
 
-int  gsl_blas_chpr (CBLAS_UPLO_t Uplo,
-                    float alpha,
-                    const gsl_vector_complex_float * X,
-                    void * Ap);
-
 int  gsl_blas_cher2 (CBLAS_UPLO_t Uplo,
-                     const gsl_complex_float * alpha,
+                     const gsl_complex_float alpha,
                      const gsl_vector_complex_float * X,
                      const gsl_vector_complex_float * Y,
                      gsl_matrix_complex_float * A);
 
-int  gsl_blas_chpr2 (CBLAS_UPLO_t Uplo,
-                     const gsl_complex_float * alpha,
-                     const gsl_vector_complex_float * X,
-                     const gsl_vector_complex_float * Y,
-                     void * Ap);
-
 int  gsl_blas_zhemv (CBLAS_UPLO_t Uplo,
-                     const gsl_complex * alpha,
+                     const gsl_complex alpha,
                      const gsl_matrix_complex * A,
                      const gsl_vector_complex * X,
-                     const gsl_complex * beta,
+                     const gsl_complex beta,
                      gsl_vector_complex * Y);
 
-int  gsl_blas_zhbmv (CBLAS_UPLO_t Uplo,
-                     int K,
-                     const gsl_complex * alpha,
-                     const gsl_matrix_complex * A,
-                     const gsl_vector_complex * X,
-                     const gsl_complex * beta,
-                     gsl_vector_complex * Y);
-
-int  gsl_blas_zhpmv (CBLAS_UPLO_t Uplo,
-                     const gsl_complex * alpha,
-                     const void * Ap,
-                     const gsl_vector_complex * X,
-                     const gsl_complex * beta,
-                     gsl_vector_complex * Y);
-
-int  gsl_blas_zgeru (const gsl_complex * alpha,
+int  gsl_blas_zgeru (const gsl_complex alpha,
                      const gsl_vector_complex * X,
                      const gsl_vector_complex * Y,
                      gsl_matrix_complex * A);
 
-int  gsl_blas_zgerc (const gsl_complex * alpha,
+int  gsl_blas_zgerc (const gsl_complex alpha,
                      const gsl_vector_complex * X,
                      const gsl_vector_complex * Y,
                      gsl_matrix_complex * A);
@@ -569,23 +356,12 @@ int  gsl_blas_zher (CBLAS_UPLO_t Uplo,
                     const gsl_vector_complex * X,
                     gsl_matrix_complex * A);
 
-int  gsl_blas_zhpr (CBLAS_UPLO_t Uplo,
-                    double alpha,
-                    const gsl_vector_complex * X,
-                    void * Ap);
-
 int  gsl_blas_zher2 (CBLAS_UPLO_t Uplo,
-                     const gsl_complex * alpha,
+                     const gsl_complex alpha,
                      const gsl_vector_complex * X,
                      const gsl_vector_complex * Y,
                      gsl_matrix_complex * A);
 
-int  gsl_blas_zhpr2 (CBLAS_UPLO_t Uplo,
-                     const gsl_complex * alpha,
-                     const gsl_vector_complex * X,
-                     const gsl_vector_complex * Y,
-                     void *Ap);
-
 /*
  * ===========================================================================
  * Prototypes for level 3 BLAS
@@ -597,7 +373,6 @@ int  gsl_blas_zhpr2 (CBLAS_UPLO_t Uplo,
  */
 int  gsl_blas_sgemm (CBLAS_TRANSPOSE_t TransA,
                      CBLAS_TRANSPOSE_t TransB,
-                     int K,
                      float alpha,
                      const gsl_matrix_float * A,
                      const gsl_matrix_float * B,
@@ -612,14 +387,12 @@ int  gsl_blas_ssymm (CBLAS_SIDE_t Side, CBLAS_UPLO_t Uplo,
                      gsl_matrix_float * C);
 
 int  gsl_blas_ssyrk (CBLAS_UPLO_t Uplo, CBLAS_TRANSPOSE_t Trans,
-                     int K,
                      float alpha,
                      const gsl_matrix_float * A,
                      float beta,
                      gsl_matrix_float * C);
 
 int  gsl_blas_ssyr2k (CBLAS_UPLO_t Uplo, CBLAS_TRANSPOSE_t Trans,
-                      int K,
                       float alpha,
                       const gsl_matrix_float * A,
                       const gsl_matrix_float * B,
@@ -642,7 +415,6 @@ int  gsl_blas_strsm (CBLAS_SIDE_t Side,
 
 int  gsl_blas_dgemm (CBLAS_TRANSPOSE_t TransA,
                      CBLAS_TRANSPOSE_t TransB,
-                     int K,
                      double alpha,
                      const gsl_matrix * A,
                      const gsl_matrix * B,
@@ -659,7 +431,6 @@ int  gsl_blas_dsymm (CBLAS_SIDE_t Side,
 
 int  gsl_blas_dsyrk (CBLAS_UPLO_t Uplo,
                      CBLAS_TRANSPOSE_t Trans,
-                     int K,
                      double alpha,
                      const gsl_matrix * A,
                      double beta,
@@ -667,7 +438,6 @@ int  gsl_blas_dsyrk (CBLAS_UPLO_t Uplo,
 
 int  gsl_blas_dsyr2k (CBLAS_UPLO_t Uplo,
                       CBLAS_TRANSPOSE_t Trans,
-                      int K,
                       double alpha,
                       const  gsl_matrix * A,
                       const  gsl_matrix * B,
@@ -690,97 +460,91 @@ int  gsl_blas_dtrsm (CBLAS_SIDE_t Side,
 
 int  gsl_blas_cgemm (CBLAS_TRANSPOSE_t TransA,
                      CBLAS_TRANSPOSE_t TransB,
-                     int K,
-                     const gsl_complex_float * alpha,
+                     const gsl_complex_float alpha,
                      const gsl_matrix_complex_float * A,
                      const gsl_matrix_complex_float * B,
-                     const gsl_complex_float * beta,
+                     const gsl_complex_float beta,
                      gsl_matrix_complex_float * C);
 
 int  gsl_blas_csymm (CBLAS_SIDE_t Side,
                      CBLAS_UPLO_t Uplo,
-                     const gsl_complex_float * alpha,
+                     const gsl_complex_float alpha,
                      const gsl_matrix_complex_float * A,
                      const gsl_matrix_complex_float * B,
-                     const gsl_complex_float * beta,
+                     const gsl_complex_float beta,
                      gsl_matrix_complex_float * C);
 
 int  gsl_blas_csyrk (CBLAS_UPLO_t Uplo,
                      CBLAS_TRANSPOSE_t Trans,
-                     int K,
-                     const gsl_complex_float * alpha,
+                     const gsl_complex_float alpha,
                      const gsl_matrix_complex_float * A,
-                     const gsl_complex_float * beta,
+                     const gsl_complex_float beta,
                      gsl_matrix_complex_float * C);
 
 int  gsl_blas_csyr2k (CBLAS_UPLO_t Uplo,
                       CBLAS_TRANSPOSE_t Trans,
-                      int K,
-                      const gsl_complex_float * alpha,
+                      const gsl_complex_float alpha,
                       const gsl_matrix_complex_float * A,
                       const gsl_matrix_complex_float * B,
-                      const gsl_complex_float * beta,
+                      const gsl_complex_float beta,
                       gsl_matrix_complex_float * C);
 
 int  gsl_blas_ctrmm (CBLAS_SIDE_t Side,
                      CBLAS_UPLO_t Uplo, CBLAS_TRANSPOSE_t TransA,
                      CBLAS_DIAG_t Diag,
-                     const gsl_complex_float * alpha,
+                     const gsl_complex_float alpha,
                      const gsl_matrix_complex_float * A,
                      gsl_matrix_complex_float * B);
 
 int  gsl_blas_ctrsm (CBLAS_SIDE_t Side,
                      CBLAS_UPLO_t Uplo, CBLAS_TRANSPOSE_t TransA,
                      CBLAS_DIAG_t Diag,
-                     const gsl_complex_float * alpha,
+                     const gsl_complex_float alpha,
                      const gsl_matrix_complex_float * A,
                      gsl_matrix_complex_float * B);
 
 int  gsl_blas_zgemm (CBLAS_TRANSPOSE_t TransA,
                      CBLAS_TRANSPOSE_t TransB,
-                     int K,
-                     const gsl_complex * alpha,
+                     const gsl_complex alpha,
                      const gsl_matrix_complex * A,
                      const gsl_matrix_complex * B,
-                     const gsl_complex * beta,
+                     const gsl_complex beta,
                      gsl_matrix_complex * C);
 
 int  gsl_blas_zsymm (CBLAS_SIDE_t Side,
                      CBLAS_UPLO_t Uplo,
-                     const gsl_complex * alpha,
+                     const gsl_complex alpha,
                      const gsl_matrix_complex * A,
                      const gsl_matrix_complex * B,
-                     const gsl_complex * beta,
+                     const gsl_complex beta,
                      gsl_matrix_complex * C);
 
 int  gsl_blas_zsyrk (CBLAS_UPLO_t Uplo,
                      CBLAS_TRANSPOSE_t Trans,
-                     int K,
-                     const gsl_complex * alpha,
+                     const gsl_complex alpha,
                      const gsl_matrix_complex * A,
-                     const gsl_complex * beta,
+                     const gsl_complex beta,
                      gsl_matrix_complex * C);
 
 int  gsl_blas_zsyr2k (CBLAS_UPLO_t Uplo,
                       CBLAS_TRANSPOSE_t Trans,
-                      int K,
-                      const gsl_complex * alpha,
+                      const gsl_complex alpha,
                       const gsl_matrix_complex * A,
                       const gsl_matrix_complex * B,
-                      const gsl_complex * beta,
+                      const gsl_complex beta,
                       gsl_matrix_complex *C);
 
 int  gsl_blas_ztrmm (CBLAS_SIDE_t Side,
                      CBLAS_UPLO_t Uplo, CBLAS_TRANSPOSE_t TransA,
                      CBLAS_DIAG_t Diag,
-                     const gsl_complex * alpha,
+                     const gsl_complex alpha,
                      const gsl_matrix_complex * A,
                      gsl_matrix_complex * B);
 
 int  gsl_blas_ztrsm (CBLAS_SIDE_t Side,
                      CBLAS_UPLO_t Uplo, CBLAS_TRANSPOSE_t TransA,
                      CBLAS_DIAG_t Diag,
-                     const gsl_complex * alpha,
+                     const gsl_complex alpha,
                      const gsl_matrix_complex * A,
                      gsl_matrix_complex * B);
 
@@ -789,15 +553,14 @@ int  gsl_blas_ztrsm (CBLAS_SIDE_t Side,
  */
 int  gsl_blas_chemm (CBLAS_SIDE_t Side,
                      CBLAS_UPLO_t Uplo,
-                     const gsl_complex_float * alpha,
+                     const gsl_complex_float alpha,
                      const gsl_matrix_complex_float * A,
                      const gsl_matrix_complex_float * B,
-                     const gsl_complex_float * beta,
+                     const gsl_complex_float beta,
                      gsl_matrix_complex_float * C);
 
 int  gsl_blas_cherk (CBLAS_UPLO_t Uplo,
                      CBLAS_TRANSPOSE_t Trans,
-                     int K,
                      float alpha,
                      const gsl_matrix_complex_float * A,
                      float beta,
@@ -805,8 +568,7 @@ int  gsl_blas_cherk (CBLAS_UPLO_t Uplo,
 
 int  gsl_blas_cher2k (CBLAS_UPLO_t Uplo,
                       CBLAS_TRANSPOSE_t Trans,
-                      int K,
-                      const gsl_complex_float * alpha,
+                      const gsl_complex_float alpha,
                       const gsl_matrix_complex_float * A,
                       const gsl_matrix_complex_float * B,
                       float beta,
@@ -814,15 +576,14 @@ int  gsl_blas_cher2k (CBLAS_UPLO_t Uplo,
 
 int  gsl_blas_zhemm (CBLAS_SIDE_t Side,
                      CBLAS_UPLO_t Uplo,
-                     const gsl_complex * alpha,
+                     const gsl_complex alpha,
                      const gsl_matrix_complex * A,
                      const gsl_matrix_complex * B,
-                     const gsl_complex * beta,
+                     const gsl_complex beta,
                      gsl_matrix_complex * C);
 
 int  gsl_blas_zherk (CBLAS_UPLO_t Uplo,
                      CBLAS_TRANSPOSE_t Trans,
-                     int K,
                      double alpha,
                      const gsl_matrix_complex * A,
                      double beta,
@@ -830,8 +591,7 @@ int  gsl_blas_zherk (CBLAS_UPLO_t Uplo,
 
 int  gsl_blas_zher2k (CBLAS_UPLO_t Uplo,
                       CBLAS_TRANSPOSE_t Trans,
-                      int K,
-                      const gsl_complex * alpha,
+                      const gsl_complex alpha,
                       const gsl_matrix_complex * A,
                       const gsl_matrix_complex * B,
                       double beta,
