@@ -17,6 +17,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <config.h>
+#include <stdlib.h>
 #include <gsl/gsl_test.h>
 #include <gsl/gsl_ieee_utils.h>
 #include <gsl/gsl_math.h>
@@ -31,6 +33,6 @@ main (void)
 
 #include "tests.c"
 
-  return gsl_test_summary();
+  exit (gsl_test_summary());
 }
 
