@@ -18,6 +18,7 @@
  */
 
 #include <config.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <gsl/gsl_ieee_utils.h>
 #include <gsl/gsl_test.h>
@@ -105,5 +106,5 @@ main (void)
       i++;
     }
 
-  return gsl_test_summary ();
+  exit (gsl_test_summary ());
 }
