@@ -18,6 +18,7 @@
  */
 
 #include <config.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
 #include <gsl/gsl_math.h>
@@ -2092,7 +2093,7 @@ int main (void)
 
   }
 
-  return gsl_test_summary() ;
+  exit (gsl_test_summary());
 } 
 
 void
