@@ -31,6 +31,7 @@
 #define REAL double
 
 #include "givens.c"
+#include "apply_givens.c"
 
 /* Factorise a general M x N matrix A into
  *
@@ -67,7 +68,7 @@
  */
 
 int
-gsl_linalg_QRPT_decomp (gsl_matrix * A, gsl_vector * tau, gsl_permutation * p, int *signum)
+gsl_linalg_QRPT_decomp (gsl_matrix * A, gsl_vector * tau, gsl_permutation * p, int *signum, gsl_vector * norm)
 {
   const size_t M = A->size1;
   const size_t N = A->size2;
@@ -78,13 +79,15 @@ gsl_linalg_QRPT_decomp (gsl_matrix * A, gsl_vector * tau, gsl_permutation * p, i
     }
   else if (p->size != N)
     {
-      GSL_ERROR ("permutation size mismatch", GSL_EBADLEN);
+      GSL_ERROR ("permutation size must be N", GSL_EBADLEN);
+    }
+  else if (norm->size != N)
+    {
+      GSL_ERROR ("norm size must be N", GSL_EBADLEN);
     }
   else
     {
       size_t i;
-      gsl_vector * work = gsl_vector_alloc (N);
-      gsl_vector * norm = gsl_vector_alloc (N);
 
       *signum = 1;
 
@@ -94,8 +97,8 @@ gsl_linalg_QRPT_decomp (gsl_matrix * A, gsl_vector * tau, gsl_permutation * p, i
 
       for (i = 0; i < N; i++)
 	{
-	  gsl_vector c = gsl_matrix_column (A, i);
-	  double x = gsl_blas_dnrm2 (&c);
+	  gsl_vector_view c = gsl_matrix_column (A, i);
+	  double x = gsl_blas_dnrm2 (&c.vector);
 	  gsl_vector_set (norm, i, x);
 	}
 
@@ -130,9 +133,10 @@ gsl_linalg_QRPT_decomp (gsl_matrix * A, gsl_vector * tau, gsl_permutation * p, i
 	     column of the matrix to a multiple of the j-th unit vector */
 
 	  {
-	    gsl_vector c_full = gsl_matrix_column (A, i);
-            gsl_vector c = gsl_vector_subvector (&c_full, i, M - i);
-	    double tau_i = gsl_linalg_householder_transform (&c);
+	    gsl_vector_view c_full = gsl_matrix_column (A, i);
+            gsl_vector_view c = gsl_vector_subvector (&c_full.vector, 
+                                                      i, M - i);
+	    double tau_i = gsl_linalg_householder_transform (&c.vector);
 
 	    gsl_vector_set (tau, i, tau_i);
 
@@ -140,9 +144,9 @@ gsl_linalg_QRPT_decomp (gsl_matrix * A, gsl_vector * tau, gsl_permutation * p, i
 
 	    if (i + 1 < N)
 	      {
-		gsl_matrix m = gsl_matrix_submatrix (A, i, i + 1, M - i, N - (i+1));
+		gsl_matrix_view m = gsl_matrix_submatrix (A, i, i + 1, M - i, N - (i+1));
 
-		gsl_linalg_householder_hm (tau_i, &c, &m, work);
+		gsl_linalg_householder_hm (tau_i, &c.vector, &m.matrix);
 	      }
 	  }
 
@@ -163,9 +167,10 @@ gsl_linalg_QRPT_decomp (gsl_matrix * A, gsl_vector * tau, gsl_permutation * p, i
                   
                   if (fabs (y / x) < sqrt (20.0) * GSL_SQRT_DBL_EPSILON)
                     {
-                      gsl_vector c_full = gsl_matrix_column (A, j);
-                      gsl_vector c = gsl_vector_subvector(&c_full, i+1, M - (i+1));
-                      y = gsl_blas_dnrm2 (&c);
+                      gsl_vector_view c_full = gsl_matrix_column (A, j);
+                      gsl_vector_view c = gsl_vector_subvector(&c_full.vector,
+                                                               i+1, M - (i+1));
+                      y = gsl_blas_dnrm2 (&c.vector);
                     }
                   
                   gsl_vector_set (norm, j, y);
@@ -173,16 +178,12 @@ gsl_linalg_QRPT_decomp (gsl_matrix * A, gsl_vector * tau, gsl_permutation * p, i
             }
         }
 
-      gsl_vector_free (work);
-      gsl_vector_free (norm);
-
       return GSL_SUCCESS;
-
     }
 }
 
 int
-gsl_linalg_QRPT_decomp2 (const gsl_matrix * A, gsl_matrix * q, gsl_matrix * r, gsl_vector * tau, gsl_permutation * p, int *signum)
+gsl_linalg_QRPT_decomp2 (const gsl_matrix * A, gsl_matrix * q, gsl_matrix * r, gsl_vector * tau, gsl_permutation * p, int *signum, gsl_vector * norm)
 {
   const size_t M = A->size1;
   const size_t N = A->size2;
@@ -201,11 +202,19 @@ gsl_linalg_QRPT_decomp2 (const gsl_matrix * A, gsl_matrix * q, gsl_matrix * r, g
     }
   else if (p->size != N)
     {
-      GSL_ERROR ("permutation size mismatch", GSL_EBADLEN);
+      GSL_ERROR ("permutation size must be N", GSL_EBADLEN);
+    }
+  else if (norm->size != N)
+    {
+      GSL_ERROR ("norm size must be N", GSL_EBADLEN);
     }
 
   gsl_matrix_memcpy (r, A);
-  gsl_linalg_QRPT_decomp (r, tau, p, signum);
+
+  gsl_linalg_QRPT_decomp (r, tau, p, signum, norm);
+
+  /* FIXME:  aliased arguments depends on behavior of unpack routine! */
+
   gsl_linalg_QR_unpack (r, tau, q, r);
 
   return GSL_SUCCESS;
