@@ -46,7 +46,19 @@ typedef struct
   int owner;
 } gsl_matrix_char;
 
-/* typedef struct gsl_matrix_char_struct gsl_matrix_char;*/
+typedef union
+{
+  gsl_matrix_char _internal_representation;  
+  gsl_matrix_char matrix;
+} gsl_matrix_char_view;
+
+typedef union
+{
+  gsl_matrix_char _internal_representation;
+  const gsl_matrix_char matrix;
+} gsl_matrix_char_const_view;
+
+/* Allocation */
 
 gsl_matrix_char * 
 gsl_matrix_char_alloc (const size_t n1, const size_t n2);
@@ -78,32 +90,99 @@ gsl_vector_char_alloc_col_from_matrix (gsl_matrix_char * m,
 
 void gsl_matrix_char_free (gsl_matrix_char * m);
 
-int gsl_matrix_char_view_from_matrix (gsl_matrix_char * m, 
-                                       gsl_matrix_char * mm,
-                                       const size_t k1,
-                                       const size_t k2,
-                                       const size_t n1, 
-                                       const size_t n2);
+/* Views */
 
-int gsl_matrix_char_view_from_vector (gsl_matrix_char * m, 
-                                       gsl_vector_char * v,
-                                       const size_t offset,
-                                       const size_t n1, 
-                                       const size_t n2);
+gsl_matrix_char_view 
+gsl_matrix_char_submatrix (gsl_matrix_char * m, 
+                            const size_t i, const size_t j, 
+                            const size_t n1, const size_t n2);
 
+gsl_vector_char_view 
+gsl_matrix_char_row (gsl_matrix_char * m, const size_t i);
 
-int gsl_matrix_char_view_from_array (gsl_matrix_char * m, 
-                                      char * base,
-                                      const size_t offset,
+gsl_vector_char_view 
+gsl_matrix_char_column (gsl_matrix_char * m, const size_t j);
+
+gsl_vector_char_view 
+gsl_matrix_char_diagonal (gsl_matrix_char * m);
+
+gsl_vector_char_view 
+gsl_matrix_char_subdiagonal (gsl_matrix_char * m, const size_t k);
+
+gsl_vector_char_view 
+gsl_matrix_char_superdiagonal (gsl_matrix_char * m, const size_t k);
+
+gsl_matrix_char_view
+gsl_matrix_char_view_array (char * base,
+                             const size_t n1, 
+                             const size_t n2);
+
+gsl_matrix_char_view
+gsl_matrix_char_view_array_with_tda (char * base, 
                                       const size_t n1, 
-                                      const size_t n2);
+                                      const size_t n2,
+                                      const size_t tda);
 
-gsl_matrix_char gsl_matrix_char_view (char * m, 
-                                        const size_t n1, 
-                                        const size_t n2);
 
-int gsl_vector_char_view_row_from_matrix (gsl_vector_char * v, gsl_matrix_char * m, const size_t i);
-int gsl_vector_char_view_col_from_matrix (gsl_vector_char * v, gsl_matrix_char * m, const size_t j);
+gsl_matrix_char_view
+gsl_matrix_char_view_vector (gsl_vector_char * v,
+                              const size_t n1, 
+                              const size_t n2);
+
+gsl_matrix_char_view
+gsl_matrix_char_view_vector_with_tda (gsl_vector_char * v,
+                                       const size_t n1, 
+                                       const size_t n2,
+                                       const size_t tda);
+
+
+gsl_matrix_char_const_view 
+gsl_matrix_char_const_submatrix (const gsl_matrix_char * m, 
+                                  const size_t i, const size_t j, 
+                                  const size_t n1, const size_t n2);
+
+gsl_vector_char_const_view 
+gsl_matrix_char_const_row (const gsl_matrix_char * m, 
+                            const size_t i);
+
+gsl_vector_char_const_view 
+gsl_matrix_char_const_column (const gsl_matrix_char * m, 
+                               const size_t j);
+
+gsl_vector_char_const_view
+gsl_matrix_char_const_diagonal (const gsl_matrix_char * m);
+
+gsl_vector_char_const_view 
+gsl_matrix_char_const_subdiagonal (const gsl_matrix_char * m, 
+                                    const size_t k);
+
+gsl_vector_char_const_view 
+gsl_matrix_char_const_superdiagonal (const gsl_matrix_char * m, 
+                                      const size_t k);
+
+gsl_matrix_char_const_view
+gsl_matrix_char_const_view_array (const char * base,
+                                   const size_t n1, 
+                                   const size_t n2);
+
+gsl_matrix_char_const_view
+gsl_matrix_char_const_view_array_with_tda (const char * base, 
+                                            const size_t n1, 
+                                            const size_t n2,
+                                            const size_t tda);
+
+gsl_matrix_char_const_view
+gsl_matrix_char_const_view_vector (const gsl_vector_char * v,
+                                    const size_t n1, 
+                                    const size_t n2);
+
+gsl_matrix_char_const_view
+gsl_matrix_char_const_view_vector_with_tda (const gsl_vector_char * v,
+                                             const size_t n1, 
+                                             const size_t n2,
+                                             const size_t tda);
+
+/* Operations */
 
 void gsl_matrix_char_set_zero (gsl_matrix_char * m);
 void gsl_matrix_char_set_identity (gsl_matrix_char * m);
@@ -127,17 +206,6 @@ int gsl_matrix_char_swap_rowcol(gsl_matrix_char * m, const size_t i, const size_
 int gsl_matrix_char_transpose (gsl_matrix_char * m);
 int gsl_matrix_char_transpose_memcpy (gsl_matrix_char * dest, const gsl_matrix_char * src);
 
-
-gsl_matrix_char gsl_matrix_char_submatrix (gsl_matrix_char * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
-gsl_vector_char gsl_matrix_char_row (gsl_matrix_char * m, const size_t i);
-gsl_vector_char gsl_matrix_char_column (gsl_matrix_char * m, const size_t j);
-gsl_vector_char gsl_matrix_char_diagonal (gsl_matrix_char * m);
-
-const gsl_matrix_char gsl_matrix_char_const_submatrix (const gsl_matrix_char * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
-const gsl_vector_char gsl_matrix_char_const_row (const gsl_matrix_char * m, const size_t i);
-const gsl_vector_char gsl_matrix_char_const_column (const gsl_matrix_char * m, const size_t j);
-const gsl_vector_char gsl_matrix_char_const_diagonal (const gsl_matrix_char * m);
-
 char gsl_matrix_char_max (const gsl_matrix_char * m);
 char gsl_matrix_char_min (const gsl_matrix_char * m);
 void gsl_matrix_char_minmax (const gsl_matrix_char * m, char * min_out, char * max_out);
