@@ -46,7 +46,19 @@ typedef struct
   int owner;
 } gsl_matrix_int;
 
-/* typedef struct gsl_matrix_int_struct gsl_matrix_int;*/
+typedef union
+{
+  gsl_matrix_int _internal_representation;  
+  gsl_matrix_int matrix;
+} gsl_matrix_int_view;
+
+typedef union
+{
+  gsl_matrix_int _internal_representation;
+  const gsl_matrix_int matrix;
+} gsl_matrix_int_const_view;
+
+/* Allocation */
 
 gsl_matrix_int * 
 gsl_matrix_int_alloc (const size_t n1, const size_t n2);
@@ -78,32 +90,99 @@ gsl_vector_int_alloc_col_from_matrix (gsl_matrix_int * m,
 
 void gsl_matrix_int_free (gsl_matrix_int * m);
 
-int gsl_matrix_int_view_from_matrix (gsl_matrix_int * m, 
-                                       gsl_matrix_int * mm,
-                                       const size_t k1,
-                                       const size_t k2,
-                                       const size_t n1, 
-                                       const size_t n2);
+/* Views */
 
-int gsl_matrix_int_view_from_vector (gsl_matrix_int * m, 
-                                       gsl_vector_int * v,
-                                       const size_t offset,
-                                       const size_t n1, 
-                                       const size_t n2);
+gsl_matrix_int_view 
+gsl_matrix_int_submatrix (gsl_matrix_int * m, 
+                            const size_t i, const size_t j, 
+                            const size_t n1, const size_t n2);
 
+gsl_vector_int_view 
+gsl_matrix_int_row (gsl_matrix_int * m, const size_t i);
 
-int gsl_matrix_int_view_from_array (gsl_matrix_int * m, 
-                                      int * base,
-                                      const size_t offset,
+gsl_vector_int_view 
+gsl_matrix_int_column (gsl_matrix_int * m, const size_t j);
+
+gsl_vector_int_view 
+gsl_matrix_int_diagonal (gsl_matrix_int * m);
+
+gsl_vector_int_view 
+gsl_matrix_int_subdiagonal (gsl_matrix_int * m, const size_t k);
+
+gsl_vector_int_view 
+gsl_matrix_int_superdiagonal (gsl_matrix_int * m, const size_t k);
+
+gsl_matrix_int_view
+gsl_matrix_int_view_array (int * base,
+                             const size_t n1, 
+                             const size_t n2);
+
+gsl_matrix_int_view
+gsl_matrix_int_view_array_with_tda (int * base, 
                                       const size_t n1, 
-                                      const size_t n2);
+                                      const size_t n2,
+                                      const size_t tda);
 
-gsl_matrix_int gsl_matrix_int_view (int * m, 
-                                        const size_t n1, 
-                                        const size_t n2);
 
-int gsl_vector_int_view_row_from_matrix (gsl_vector_int * v, gsl_matrix_int * m, const size_t i);
-int gsl_vector_int_view_col_from_matrix (gsl_vector_int * v, gsl_matrix_int * m, const size_t j);
+gsl_matrix_int_view
+gsl_matrix_int_view_vector (gsl_vector_int * v,
+                              const size_t n1, 
+                              const size_t n2);
+
+gsl_matrix_int_view
+gsl_matrix_int_view_vector_with_tda (gsl_vector_int * v,
+                                       const size_t n1, 
+                                       const size_t n2,
+                                       const size_t tda);
+
+
+gsl_matrix_int_const_view 
+gsl_matrix_int_const_submatrix (const gsl_matrix_int * m, 
+                                  const size_t i, const size_t j, 
+                                  const size_t n1, const size_t n2);
+
+gsl_vector_int_const_view 
+gsl_matrix_int_const_row (const gsl_matrix_int * m, 
+                            const size_t i);
+
+gsl_vector_int_const_view 
+gsl_matrix_int_const_column (const gsl_matrix_int * m, 
+                               const size_t j);
+
+gsl_vector_int_const_view
+gsl_matrix_int_const_diagonal (const gsl_matrix_int * m);
+
+gsl_vector_int_const_view 
+gsl_matrix_int_const_subdiagonal (const gsl_matrix_int * m, 
+                                    const size_t k);
+
+gsl_vector_int_const_view 
+gsl_matrix_int_const_superdiagonal (const gsl_matrix_int * m, 
+                                      const size_t k);
+
+gsl_matrix_int_const_view
+gsl_matrix_int_const_view_array (const int * base,
+                                   const size_t n1, 
+                                   const size_t n2);
+
+gsl_matrix_int_const_view
+gsl_matrix_int_const_view_array_with_tda (const int * base, 
+                                            const size_t n1, 
+                                            const size_t n2,
+                                            const size_t tda);
+
+gsl_matrix_int_const_view
+gsl_matrix_int_const_view_vector (const gsl_vector_int * v,
+                                    const size_t n1, 
+                                    const size_t n2);
+
+gsl_matrix_int_const_view
+gsl_matrix_int_const_view_vector_with_tda (const gsl_vector_int * v,
+                                             const size_t n1, 
+                                             const size_t n2,
+                                             const size_t tda);
+
+/* Operations */
 
 void gsl_matrix_int_set_zero (gsl_matrix_int * m);
 void gsl_matrix_int_set_identity (gsl_matrix_int * m);
@@ -127,17 +206,6 @@ int gsl_matrix_int_swap_rowcol(gsl_matrix_int * m, const size_t i, const size_t
 int gsl_matrix_int_transpose (gsl_matrix_int * m);
 int gsl_matrix_int_transpose_memcpy (gsl_matrix_int * dest, const gsl_matrix_int * src);
 
-
-gsl_matrix_int gsl_matrix_int_submatrix (gsl_matrix_int * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
-gsl_vector_int gsl_matrix_int_row (gsl_matrix_int * m, const size_t i);
-gsl_vector_int gsl_matrix_int_column (gsl_matrix_int * m, const size_t j);
-gsl_vector_int gsl_matrix_int_diagonal (gsl_matrix_int * m);
-
-const gsl_matrix_int gsl_matrix_int_const_submatrix (const gsl_matrix_int * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
-const gsl_vector_int gsl_matrix_int_const_row (const gsl_matrix_int * m, const size_t i);
-const gsl_vector_int gsl_matrix_int_const_column (const gsl_matrix_int * m, const size_t j);
-const gsl_vector_int gsl_matrix_int_const_diagonal (const gsl_matrix_int * m);
-
 int gsl_matrix_int_max (const gsl_matrix_int * m);
 int gsl_matrix_int_min (const gsl_matrix_int * m);
 void gsl_matrix_int_minmax (const gsl_matrix_int * m, int * min_out, int * max_out);
