@@ -46,7 +46,19 @@ typedef struct
   int owner;
 } gsl_matrix_short;
 
-/* typedef struct gsl_matrix_short_struct gsl_matrix_short;*/
+typedef union
+{
+  gsl_matrix_short _internal_representation;  
+  gsl_matrix_short matrix;
+} gsl_matrix_short_view;
+
+typedef union
+{
+  gsl_matrix_short _internal_representation;
+  const gsl_matrix_short matrix;
+} gsl_matrix_short_const_view;
+
+/* Allocation */
 
 gsl_matrix_short * 
 gsl_matrix_short_alloc (const size_t n1, const size_t n2);
@@ -78,32 +90,99 @@ gsl_vector_short_alloc_col_from_matrix (gsl_matrix_short * m,
 
 void gsl_matrix_short_free (gsl_matrix_short * m);
 
-int gsl_matrix_short_view_from_matrix (gsl_matrix_short * m, 
-                                       gsl_matrix_short * mm,
-                                       const size_t k1,
-                                       const size_t k2,
-                                       const size_t n1, 
-                                       const size_t n2);
+/* Views */
 
-int gsl_matrix_short_view_from_vector (gsl_matrix_short * m, 
-                                       gsl_vector_short * v,
-                                       const size_t offset,
-                                       const size_t n1, 
-                                       const size_t n2);
+gsl_matrix_short_view 
+gsl_matrix_short_submatrix (gsl_matrix_short * m, 
+                            const size_t i, const size_t j, 
+                            const size_t n1, const size_t n2);
 
+gsl_vector_short_view 
+gsl_matrix_short_row (gsl_matrix_short * m, const size_t i);
 
-int gsl_matrix_short_view_from_array (gsl_matrix_short * m, 
-                                      short * base,
-                                      const size_t offset,
+gsl_vector_short_view 
+gsl_matrix_short_column (gsl_matrix_short * m, const size_t j);
+
+gsl_vector_short_view 
+gsl_matrix_short_diagonal (gsl_matrix_short * m);
+
+gsl_vector_short_view 
+gsl_matrix_short_subdiagonal (gsl_matrix_short * m, const size_t k);
+
+gsl_vector_short_view 
+gsl_matrix_short_superdiagonal (gsl_matrix_short * m, const size_t k);
+
+gsl_matrix_short_view
+gsl_matrix_short_view_array (short * base,
+                             const size_t n1, 
+                             const size_t n2);
+
+gsl_matrix_short_view
+gsl_matrix_short_view_array_with_tda (short * base, 
                                       const size_t n1, 
-                                      const size_t n2);
+                                      const size_t n2,
+                                      const size_t tda);
 
-gsl_matrix_short gsl_matrix_short_view (short * m, 
-                                        const size_t n1, 
-                                        const size_t n2);
 
-int gsl_vector_short_view_row_from_matrix (gsl_vector_short * v, gsl_matrix_short * m, const size_t i);
-int gsl_vector_short_view_col_from_matrix (gsl_vector_short * v, gsl_matrix_short * m, const size_t j);
+gsl_matrix_short_view
+gsl_matrix_short_view_vector (gsl_vector_short * v,
+                              const size_t n1, 
+                              const size_t n2);
+
+gsl_matrix_short_view
+gsl_matrix_short_view_vector_with_tda (gsl_vector_short * v,
+                                       const size_t n1, 
+                                       const size_t n2,
+                                       const size_t tda);
+
+
+gsl_matrix_short_const_view 
+gsl_matrix_short_const_submatrix (const gsl_matrix_short * m, 
+                                  const size_t i, const size_t j, 
+                                  const size_t n1, const size_t n2);
+
+gsl_vector_short_const_view 
+gsl_matrix_short_const_row (const gsl_matrix_short * m, 
+                            const size_t i);
+
+gsl_vector_short_const_view 
+gsl_matrix_short_const_column (const gsl_matrix_short * m, 
+                               const size_t j);
+
+gsl_vector_short_const_view
+gsl_matrix_short_const_diagonal (const gsl_matrix_short * m);
+
+gsl_vector_short_const_view 
+gsl_matrix_short_const_subdiagonal (const gsl_matrix_short * m, 
+                                    const size_t k);
+
+gsl_vector_short_const_view 
+gsl_matrix_short_const_superdiagonal (const gsl_matrix_short * m, 
+                                      const size_t k);
+
+gsl_matrix_short_const_view
+gsl_matrix_short_const_view_array (const short * base,
+                                   const size_t n1, 
+                                   const size_t n2);
+
+gsl_matrix_short_const_view
+gsl_matrix_short_const_view_array_with_tda (const short * base, 
+                                            const size_t n1, 
+                                            const size_t n2,
+                                            const size_t tda);
+
+gsl_matrix_short_const_view
+gsl_matrix_short_const_view_vector (const gsl_vector_short * v,
+                                    const size_t n1, 
+                                    const size_t n2);
+
+gsl_matrix_short_const_view
+gsl_matrix_short_const_view_vector_with_tda (const gsl_vector_short * v,
+                                             const size_t n1, 
+                                             const size_t n2,
+                                             const size_t tda);
+
+/* Operations */
 
 void gsl_matrix_short_set_zero (gsl_matrix_short * m);
 void gsl_matrix_short_set_identity (gsl_matrix_short * m);
@@ -127,17 +206,6 @@ int gsl_matrix_short_swap_rowcol(gsl_matrix_short * m, const size_t i, const siz
 int gsl_matrix_short_transpose (gsl_matrix_short * m);
 int gsl_matrix_short_transpose_memcpy (gsl_matrix_short * dest, const gsl_matrix_short * src);
 
-
-gsl_matrix_short gsl_matrix_short_submatrix (gsl_matrix_short * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
-gsl_vector_short gsl_matrix_short_row (gsl_matrix_short * m, const size_t i);
-gsl_vector_short gsl_matrix_short_column (gsl_matrix_short * m, const size_t j);
-gsl_vector_short gsl_matrix_short_diagonal (gsl_matrix_short * m);
-
-const gsl_matrix_short gsl_matrix_short_const_submatrix (const gsl_matrix_short * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
-const gsl_vector_short gsl_matrix_short_const_row (const gsl_matrix_short * m, const size_t i);
-const gsl_vector_short gsl_matrix_short_const_column (const gsl_matrix_short * m, const size_t j);
-const gsl_vector_short gsl_matrix_short_const_diagonal (const gsl_matrix_short * m);
-
 short gsl_matrix_short_max (const gsl_matrix_short * m);
 short gsl_matrix_short_min (const gsl_matrix_short * m);
 void gsl_matrix_short_minmax (const gsl_matrix_short * m, short * min_out, short * max_out);
