@@ -46,7 +46,19 @@ typedef struct
   int owner;
 } gsl_matrix_ulong;
 
-/* typedef struct gsl_matrix_ulong_struct gsl_matrix_ulong;*/
+typedef union
+{
+  gsl_matrix_ulong _internal_representation;  
+  gsl_matrix_ulong matrix;
+} gsl_matrix_ulong_view;
+
+typedef union
+{
+  gsl_matrix_ulong _internal_representation;
+  const gsl_matrix_ulong matrix;
+} gsl_matrix_ulong_const_view;
+
+/* Allocation */
 
 gsl_matrix_ulong * 
 gsl_matrix_ulong_alloc (const size_t n1, const size_t n2);
@@ -78,32 +90,99 @@ gsl_vector_ulong_alloc_col_from_matrix (gsl_matrix_ulong * m,
 
 void gsl_matrix_ulong_free (gsl_matrix_ulong * m);
 
-int gsl_matrix_ulong_view_from_matrix (gsl_matrix_ulong * m, 
-                                       gsl_matrix_ulong * mm,
-                                       const size_t k1,
-                                       const size_t k2,
-                                       const size_t n1, 
-                                       const size_t n2);
+/* Views */
 
-int gsl_matrix_ulong_view_from_vector (gsl_matrix_ulong * m, 
-                                       gsl_vector_ulong * v,
-                                       const size_t offset,
-                                       const size_t n1, 
-                                       const size_t n2);
+gsl_matrix_ulong_view 
+gsl_matrix_ulong_submatrix (gsl_matrix_ulong * m, 
+                            const size_t i, const size_t j, 
+                            const size_t n1, const size_t n2);
 
+gsl_vector_ulong_view 
+gsl_matrix_ulong_row (gsl_matrix_ulong * m, const size_t i);
 
-int gsl_matrix_ulong_view_from_array (gsl_matrix_ulong * m, 
-                                      unsigned long * base,
-                                      const size_t offset,
+gsl_vector_ulong_view 
+gsl_matrix_ulong_column (gsl_matrix_ulong * m, const size_t j);
+
+gsl_vector_ulong_view 
+gsl_matrix_ulong_diagonal (gsl_matrix_ulong * m);
+
+gsl_vector_ulong_view 
+gsl_matrix_ulong_subdiagonal (gsl_matrix_ulong * m, const size_t k);
+
+gsl_vector_ulong_view 
+gsl_matrix_ulong_superdiagonal (gsl_matrix_ulong * m, const size_t k);
+
+gsl_matrix_ulong_view
+gsl_matrix_ulong_view_array (unsigned long * base,
+                             const size_t n1, 
+                             const size_t n2);
+
+gsl_matrix_ulong_view
+gsl_matrix_ulong_view_array_with_tda (unsigned long * base, 
                                       const size_t n1, 
-                                      const size_t n2);
+                                      const size_t n2,
+                                      const size_t tda);
 
-gsl_matrix_ulong gsl_matrix_ulong_view (unsigned long * m, 
-                                        const size_t n1, 
-                                        const size_t n2);
 
-int gsl_vector_ulong_view_row_from_matrix (gsl_vector_ulong * v, gsl_matrix_ulong * m, const size_t i);
-int gsl_vector_ulong_view_col_from_matrix (gsl_vector_ulong * v, gsl_matrix_ulong * m, const size_t j);
+gsl_matrix_ulong_view
+gsl_matrix_ulong_view_vector (gsl_vector_ulong * v,
+                              const size_t n1, 
+                              const size_t n2);
+
+gsl_matrix_ulong_view
+gsl_matrix_ulong_view_vector_with_tda (gsl_vector_ulong * v,
+                                       const size_t n1, 
+                                       const size_t n2,
+                                       const size_t tda);
+
+
+gsl_matrix_ulong_const_view 
+gsl_matrix_ulong_const_submatrix (const gsl_matrix_ulong * m, 
+                                  const size_t i, const size_t j, 
+                                  const size_t n1, const size_t n2);
+
+gsl_vector_ulong_const_view 
+gsl_matrix_ulong_const_row (const gsl_matrix_ulong * m, 
+                            const size_t i);
+
+gsl_vector_ulong_const_view 
+gsl_matrix_ulong_const_column (const gsl_matrix_ulong * m, 
+                               const size_t j);
+
+gsl_vector_ulong_const_view
+gsl_matrix_ulong_const_diagonal (const gsl_matrix_ulong * m);
+
+gsl_vector_ulong_const_view 
+gsl_matrix_ulong_const_subdiagonal (const gsl_matrix_ulong * m, 
+                                    const size_t k);
+
+gsl_vector_ulong_const_view 
+gsl_matrix_ulong_const_superdiagonal (const gsl_matrix_ulong * m, 
+                                      const size_t k);
+
+gsl_matrix_ulong_const_view
+gsl_matrix_ulong_const_view_array (const unsigned long * base,
+                                   const size_t n1, 
+                                   const size_t n2);
+
+gsl_matrix_ulong_const_view
+gsl_matrix_ulong_const_view_array_with_tda (const unsigned long * base, 
+                                            const size_t n1, 
+                                            const size_t n2,
+                                            const size_t tda);
+
+gsl_matrix_ulong_const_view
+gsl_matrix_ulong_const_view_vector (const gsl_vector_ulong * v,
+                                    const size_t n1, 
+                                    const size_t n2);
+
+gsl_matrix_ulong_const_view
+gsl_matrix_ulong_const_view_vector_with_tda (const gsl_vector_ulong * v,
+                                             const size_t n1, 
+                                             const size_t n2,
+                                             const size_t tda);
+
+/* Operations */
 
 void gsl_matrix_ulong_set_zero (gsl_matrix_ulong * m);
 void gsl_matrix_ulong_set_identity (gsl_matrix_ulong * m);
@@ -127,17 +206,6 @@ int gsl_matrix_ulong_swap_rowcol(gsl_matrix_ulong * m, const size_t i, const siz
 int gsl_matrix_ulong_transpose (gsl_matrix_ulong * m);
 int gsl_matrix_ulong_transpose_memcpy (gsl_matrix_ulong * dest, const gsl_matrix_ulong * src);
 
-
-gsl_matrix_ulong gsl_matrix_ulong_submatrix (gsl_matrix_ulong * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
-gsl_vector_ulong gsl_matrix_ulong_row (gsl_matrix_ulong * m, const size_t i);
-gsl_vector_ulong gsl_matrix_ulong_column (gsl_matrix_ulong * m, const size_t j);
-gsl_vector_ulong gsl_matrix_ulong_diagonal (gsl_matrix_ulong * m);
-
-const gsl_matrix_ulong gsl_matrix_ulong_const_submatrix (const gsl_matrix_ulong * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
-const gsl_vector_ulong gsl_matrix_ulong_const_row (const gsl_matrix_ulong * m, const size_t i);
-const gsl_vector_ulong gsl_matrix_ulong_const_column (const gsl_matrix_ulong * m, const size_t j);
-const gsl_vector_ulong gsl_matrix_ulong_const_diagonal (const gsl_matrix_ulong * m);
-
 unsigned long gsl_matrix_ulong_max (const gsl_matrix_ulong * m);
 unsigned long gsl_matrix_ulong_min (const gsl_matrix_ulong * m);
 void gsl_matrix_ulong_minmax (const gsl_matrix_ulong * m, unsigned long * min_out, unsigned long * max_out);
