@@ -17,6 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <config.h>
+#include <stdlib.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_min.h>
 #include <gsl/gsl_errno.h>
@@ -76,7 +77,7 @@ main (void)
   test_bracket("sqrt(|x|) [-1,-0.6]",&F_func2,-1.0,-0.6,15);
   test_bracket("sqrt(|x|) [-1,1]",&F_func2,-1.0,1.0,15);
 
-  return gsl_test_summary ();
+  exit (gsl_test_summary ());
 }
 
 void
