@@ -18,6 +18,7 @@
  */
 
 #include <config.h>
+#include <stdlib.h>
 #include <gsl/gsl_test.h>
 #include <gsl/gsl_multimin.h>
 #include <gsl/gsl_min.h>
@@ -177,5 +178,5 @@ main (void)
       T++;
     }
 
-  return gsl_test_summary();
+  exit (gsl_test_summary());
 }
