@@ -35,8 +35,9 @@ main (int argc, char *argv[])
 {
   size_t i,j;
   size_t n = 0;
-  double mu = 0, nu = 0, nu1 = 0, nu2 = 0, sigma = 0, a = 0, b = 0, p = 0;
+  double mu = 0, nu = 0, nu1 = 0, nu2 = 0, sigma = 0, a = 0, b = 0, c = 0;
   double zeta = 0, sigmax = 0, sigmay = 0, rho = 0;
+  double p = 0;
   double x = 0, y =0, z=0  ;
   unsigned int N = 0, t = 0, n1 = 0, n2 = 0 ;
   unsigned long int seed = 0 ;
@@ -72,6 +73,7 @@ main (int argc, char *argv[])
 "  hypergeometric\n"
 "  laplace\n"
 "  levy\n"
+"  levy-skew\n"
 "  logarithmic\n"
 "  logistic\n"
 "  lognormal\n"
@@ -137,9 +139,9 @@ main (int argc, char *argv[])
     }
   else if (NAME("cauchy"))
     {
-      ARGS(1, "mu = scale parameter");
-      DBL_ARG(mu)
-      OUTPUT(gsl_ran_cauchy (r, mu));
+      ARGS(1, "a = scale parameter");
+      DBL_ARG(a)
+      OUTPUT(gsl_ran_cauchy (r, a));
     }
   else if (NAME("chisq"))
     {
@@ -162,10 +164,10 @@ main (int argc, char *argv[])
     }
   else if (NAME("exppow"))
     {
-      ARGS(2, "mu = scale parameter, a = power (1=exponential, 2=gaussian)");
-      DBL_ARG(mu) ;
+      ARGS(2, "a = scale parameter, b = power (1=exponential, 2=gaussian)");
       DBL_ARG(a) ;
-      OUTPUT(gsl_ran_exppow (r, mu, a));
+      DBL_ARG(b) ;
+      OUTPUT(gsl_ran_exppow (r, a, b));
     }
   else if (NAME("fdist"))
     {
@@ -234,7 +236,7 @@ main (int argc, char *argv[])
       double *xarr;  
       ARGS(1, "n1 = number of dimensions of hypersphere"); 
       INT_ARG(n1) ;
-      xarr = malloc(n1*sizeof(double));
+      xarr = (double *)malloc(n1*sizeof(double));
 
       for(i = 0; i < n; i++) { 
         gsl_ran_dir_nd (r, n1, xarr) ; 
@@ -277,16 +279,24 @@ main (int argc, char *argv[])
     }
   else if (NAME("laplace"))
     {
-      ARGS(1, "mu = scale parameter");
-      DBL_ARG(mu) ;
-      OUTPUT(gsl_ran_laplace (r, mu));
+      ARGS(1, "a = scale parameter");
+      DBL_ARG(a) ;
+      OUTPUT(gsl_ran_laplace (r, a));
     }
   else if (NAME("levy"))
     {
-      ARGS(2, "mu = scale parameter, a = power (1=cauchy, 2=gaussian)");
-      DBL_ARG(mu) ;
+      ARGS(2, "c = scale, a = power (1=cauchy, 2=gaussian)");
+      DBL_ARG(c) ;
       DBL_ARG(a) ;
-      OUTPUT(gsl_ran_levy (r, mu, a));
+      OUTPUT(gsl_ran_levy (r, c, a));
+    }
+  else if (NAME("levy-skew"))
+    {
+      ARGS(3, "c = scale, a = power (1=cauchy, 2=gaussian), b = skew");
+      DBL_ARG(c) ;
+      DBL_ARG(a) ;
+      DBL_ARG(b) ;
+      OUTPUT(gsl_ran_levy_skew (r, c, a, b));
     }
   else if (NAME("logarithmic"))
     {
@@ -296,9 +306,9 @@ main (int argc, char *argv[])
     }
   else if (NAME("logistic"))
     {
-      ARGS(1, "mu = scale parameter");
-      DBL_ARG(mu) ;
-      OUTPUT(gsl_ran_logistic (r, mu));
+      ARGS(1, "a = scale parameter");
+      DBL_ARG(a) ;
+      OUTPUT(gsl_ran_logistic (r, a));
     }
   else if (NAME("lognormal"))
     {
@@ -317,9 +327,9 @@ main (int argc, char *argv[])
   else if (NAME("pareto"))
     {
       ARGS(2, "a = power, b = scale parameter");
-      DBL_ARG(mu) ;
       DBL_ARG(a) ;
-      OUTPUT(gsl_ran_pareto (r, mu, a));
+      DBL_ARG(b) ;
+      OUTPUT(gsl_ran_pareto (r, a, b));
     }
   else if (NAME("pascal"))
     {
@@ -355,10 +365,10 @@ main (int argc, char *argv[])
     }
   else if (NAME("weibull"))
     {
-      ARGS(2, "mu = scale parameter, a = exponent");
-      DBL_ARG(mu) ;
+      ARGS(2, "a = scale parameter, b = exponent");
       DBL_ARG(a) ;
-      OUTPUT(gsl_ran_weibull (r, mu, a));
+      DBL_ARG(b) ;
+      OUTPUT(gsl_ran_weibull (r, a, b));
     }
   else
     {
