@@ -18,6 +18,7 @@
  */
 
 #include <config.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
 #include <gsl/gsl_rng.h>
@@ -153,7 +154,7 @@ main (void)
   for (r = rngs ; *r != 0; r++)
     generic_rng_test (*r);
 
-  return gsl_test_summary ();
+  exit (gsl_test_summary ());
 }
 
 
