@@ -18,7 +18,7 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: elementary.c,v 1.12 2001/04/23 09:38:29 bjg Exp $
+ * RCS:     $Id: elementary.c,v 1.13 2001/06/29 08:03:04 bjg Exp $
  */
 #include <config.h>
 #include <gsl/gsl_math.h>
@@ -51,12 +51,7 @@ gsl_sf_multiply_e(const double x, const double y, gsl_sf_result * result)
     const double min = GSL_MIN_DBL(fabs(x), fabs(y));
     const double max = GSL_MAX_DBL(fabs(x), fabs(y));
     if(max < 0.9 * GSL_SQRT_DBL_MAX || min < (f * DBL_MAX)/max) {
-      /* FIXME: temporary trick with volatile until we understand
-         what is wrong with the " == 0.0" test.
-       */
-      /* result->val = x*y; */
-      volatile double tmp = x*y;
-      result->val = tmp;
+      result->val = GSL_COERCE_DBL(x*y);
       result->err = 2.0 * GSL_DBL_EPSILON * fabs(result->val);
       return (result->val == 0.0 ? GSL_EUNDRFLW : GSL_SUCCESS);
     }
