@@ -1,5 +1,5 @@
 /* Author:  G. Jungman
- * RCS:     $Id: gsl_sf.h,v 1.20 2000/03/13 19:47:21 bjg Exp $
+ * RCS:     $Id: gsl_sf.h,v 1.22 2001/04/30 11:52:17 bjg Exp $
  */
 #ifndef __GSL_SF_H__
 #define __GSL_SF_H__
@@ -8,7 +8,6 @@
 
 #include <gsl/gsl_sf_airy.h>
 #include <gsl/gsl_sf_bessel.h>
-#include <gsl/gsl_sf_chebyshev.h>
 #include <gsl/gsl_sf_clausen.h>
 #include <gsl/gsl_sf_coupling.h>
 #include <gsl/gsl_sf_coulomb.h>
@@ -28,7 +27,6 @@
 #include <gsl/gsl_sf_laguerre.h>
 #include <gsl/gsl_sf_legendre.h>
 #include <gsl/gsl_sf_log.h>
-#include <gsl/gsl_sf_poly.h>
 #include <gsl/gsl_sf_pow_int.h>
 #include <gsl/gsl_sf_psi.h>
 #include <gsl/gsl_sf_synchrotron.h>
