@@ -18,6 +18,7 @@
  */
 
 #include <config.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_test.h>
@@ -259,7 +260,7 @@ main (void)
     gsl_test_rel (x, 2.0/3.0, 4*GSL_DBL_EPSILON, "gsl_fdiv(2,3)");
   }
 
-  return gsl_test_summary ();
+  exit (gsl_test_summary ());
 }
 
 
