@@ -30,14 +30,40 @@
 #undef TYPE
 #endif
 
+#ifdef REAL_TYPE
+#undef REAL_TYPE
+#endif
+
 #ifdef QUALIFIED_TYPE
 #undef QUALIFIED_TYPE
 #endif
 
+#ifdef QUALIFIED_VIEW
+#undef QUALIFIED_VIEW
+#endif
+
+#ifdef QUALIFIED_REAL_TYPE
+#undef QUALIFIED_REAL_TYPE
+#endif
+
+#ifdef QUALIFIED_REAL_VIEW
+#undef QUALIFIED_REAL_VIEW
+#endif
+
 #ifdef USES_LONGDOUBLE
 #undef USES_LONGDOUBLE
 #endif
 
+#ifdef SHORT_REAL
+#undef SHORT_REAL
+#endif
+
+#ifndef USE_QUALIFIER
+#ifdef QUALIFIER
+#undef QUALIFIER
+#endif
+#endif
+
 #undef BASE
 #undef BASE_EPSILON
 #undef SHORT
