@@ -7,6 +7,7 @@
 #if   defined(BASE_GSL_COMPLEX_LONG)
 #define BASE gsl_complex_long_double
 #define SHORT complex_long_double
+#define SHORT_REAL long_double
 #define ATOMIC long double
 #define USES_LONGDOUBLE 1
 #define MULTIPLICITY 2
@@ -19,6 +20,7 @@
 #elif defined(BASE_GSL_COMPLEX)
 #define BASE gsl_complex
 #define SHORT complex
+#define SHORT_REAL
 #define ATOMIC double
 #define MULTIPLICITY 2
 #define IN_FORMAT "%lg"
@@ -30,6 +32,7 @@
 #elif defined(BASE_GSL_COMPLEX_FLOAT)
 #define BASE gsl_complex_float
 #define SHORT complex_float
+#define SHORT_REAL float
 #define ATOMIC float
 #define MULTIPLICITY 2
 #define IN_FORMAT "%g"
@@ -173,25 +176,51 @@
 #define CONCAT4x(a,b,c,d) a ## _ ## b ## _ ## c ## _ ## d
 #define CONCAT4(a,b,c,d) CONCAT4x(a,b,c,d)
 
+#ifndef USE_QUALIFIER
+#define QUALIFIER
+#endif
+
 #ifdef USE_QUALIFIER
 #if defined(BASE_DOUBLE)
 #define FUNCTION(dir,name) CONCAT3(dir,QUALIFIER,name)
 #define TYPE(dir) dir
 #define QUALIFIED_TYPE(dir) QUALIFIER dir
+#define QUALIFIED_VIEW(dir,name) CONCAT3(dir,QUALIFIER,name)
 #else
 #define FUNCTION(a,c) CONCAT4(a,SHORT,QUALIFIER,c)
 #define TYPE(dir) CONCAT2(dir,SHORT)
 #define QUALIFIED_TYPE(dir) QUALIFIER CONCAT2(dir,SHORT)
+#define QUALIFIED_VIEW(dir,name) CONCAT4(dir,SHORT,QUALIFIER,name)
+#endif
+#if defined(BASE_GSL_COMPLEX)
+#define REAL_TYPE(dir) dir
+#define QUALIFIED_REAL_TYPE(dir) QUALIFIER dir
+#define QUALIFIED_REAL_VIEW(dir,name) CONCAT3(dir,QUALIFIER,name)
+#else
+#define REAL_TYPE(dir) CONCAT2(dir,SHORT_REAL)
+#define QUALIFIED_REAL_TYPE(dir) QUALIFIER CONCAT2(dir,SHORT_REAL)
+#define QUALIFIED_REAL_VIEW(dir,name) CONCAT4(dir,SHORT_REAL,QUALIFIER,name)
 #endif
 #else
 #if defined(BASE_DOUBLE)
 #define FUNCTION(dir,name) CONCAT2(dir,name)
 #define TYPE(dir) dir
 #define QUALIFIED_TYPE(dir) TYPE(dir)
+#define QUALIFIED_VIEW(dir,name) CONCAT2(dir,name)
 #else
 #define FUNCTION(a,c) CONCAT3(a,SHORT,c)
 #define TYPE(dir) CONCAT2(dir,SHORT)
 #define QUALIFIED_TYPE(dir) TYPE(dir)
+#define QUALIFIED_VIEW(dir,name) CONCAT3(dir,SHORT,name)
+#endif
+#if defined(BASE_GSL_COMPLEX)
+#define REAL_TYPE(dir) dir
+#define QUALIFIED_REAL_TYPE(dir) dir
+#define QUALIFIED_REAL_VIEW(dir,name) CONCAT2(dir,name)
+#else
+#define REAL_TYPE(dir) CONCAT2(dir,SHORT_REAL)
+#define QUALIFIED_REAL_TYPE(dir) CONCAT2(dir,SHORT_REAL)
+#define QUALIFIED_REAL_VIEW(dir,name) CONCAT3(dir,SHORT_REAL,name)
 #endif
 #endif
 
