@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_complex.h>
+#include <gsl/gsl_vector_long_double.h>
 #include <gsl/gsl_vector_complex.h>
 #include <gsl/gsl_block_complex_long_double.h>
 
@@ -38,50 +39,105 @@
 
 __BEGIN_DECLS
 
-struct gsl_vector_complex_long_double_struct
+typedef struct 
 {
   size_t size;
   size_t stride;
   long double *data;
   gsl_block_complex_long_double *block;
   int owner;
-};
+} gsl_vector_complex_long_double;
 
-typedef struct gsl_vector_complex_long_double_struct gsl_vector_complex_long_double;
+typedef union
+{
+  gsl_vector_complex_long_double _internal_representation;  
+  gsl_vector_complex_long_double vector;
+} gsl_vector_complex_long_double_view;
+
+typedef union
+{
+  gsl_vector_complex_long_double _internal_representation;
+  const gsl_vector_complex_long_double vector;
+} gsl_vector_complex_long_double_const_view;
+
+/* Allocation */
 
 gsl_vector_complex_long_double *gsl_vector_complex_long_double_alloc (const size_t n);
 gsl_vector_complex_long_double *gsl_vector_complex_long_double_calloc (const size_t n);
 
-gsl_vector_complex_long_double gsl_vector_complex_long_double_view (long double * v, size_t n);
+gsl_vector_complex_long_double *
+gsl_vector_complex_long_double_alloc_from_block (gsl_block_complex_long_double * b, 
+                                           const size_t offset, 
+                                           const size_t n, 
+                                           const size_t stride);
 
-gsl_vector_complex_long_double 
-*gsl_vector_complex_long_double_alloc_from_block (gsl_block_complex_long_double * b, 
-                                            const size_t offset, 
-                                            const size_t n, 
-                                            const size_t stride);
-
-gsl_vector_complex_long_double 
-*gsl_vector_complex_long_double_alloc_from_vector (gsl_vector_complex_long_double * v, 
+gsl_vector_complex_long_double *
+gsl_vector_complex_long_double_alloc_from_vector (gsl_vector_complex_long_double * v, 
                                              const size_t offset, 
                                              const size_t n, 
                                              const size_t stride);
 
 void gsl_vector_complex_long_double_free (gsl_vector_complex_long_double * v);
 
-int gsl_vector_complex_long_double_view_from_vector (gsl_vector_complex_long_double *v, 
-                                               gsl_vector_complex_long_double *base,
-                                               size_t offset, size_t n, size_t stride);
+/* Views */
 
-int gsl_vector_complex_long_double_view_from_array (gsl_vector_complex_long_double *v, 
-                                              long double *base,
-                                              size_t offset, size_t n, size_t stride);
+gsl_vector_complex_long_double_view
+gsl_vector_complex_long_double_view_array (long double *base,
+                                     size_t n);
 
-gsl_vector_complex_long_double gsl_vector_complex_long_double_subvector (gsl_vector_complex_long_double *v, size_t i, size_t n);
-gsl_vector_complex_long_double gsl_vector_complex_long_double_subvector_with_stride (gsl_vector_complex_long_double *v, size_t i, size_t n, size_t stride);
+gsl_vector_complex_long_double_view
+gsl_vector_complex_long_double_view_array_with_stride (long double *base,
+                                                 size_t n, 
+                                                 size_t stride);
 
-const gsl_vector_complex_long_double gsl_vector_complex_long_double_const_subvector (const gsl_vector_complex_long_double *v, size_t i, size_t n);
-const gsl_vector_complex_long_double gsl_vector_complex_long_double_const_subvector_with_stride (const gsl_vector_complex_long_double *v, size_t i, size_t n, size_t stride);
+gsl_vector_complex_long_double_const_view
+gsl_vector_complex_long_double_const_view_array (const long double *base,
+                                           size_t n);
 
+gsl_vector_complex_long_double_const_view
+gsl_vector_complex_long_double_const_view_array_with_stride (const long double *base,
+                                                       size_t offset, 
+                                                       size_t n, 
+                                                       size_t stride);
+
+gsl_vector_complex_long_double_view
+gsl_vector_complex_long_double_subvector (gsl_vector_complex_long_double *base,
+                                         size_t i, 
+                                         size_t n);
+
+
+gsl_vector_complex_long_double_view 
+gsl_vector_complex_long_double_subvector_with_stride (gsl_vector_complex_long_double *v, 
+                                                size_t i, 
+                                                size_t n, 
+                                                size_t stride);
+
+gsl_vector_complex_long_double_const_view
+gsl_vector_complex_long_double_const_subvector (const gsl_vector_complex_long_double *base,
+                                               size_t i, 
+                                               size_t n);
+
+
+gsl_vector_complex_long_double_const_view 
+gsl_vector_complex_long_double_const_subvector_with_stride (const gsl_vector_complex_long_double *v, 
+                                                      size_t i, 
+                                                      size_t n, 
+                                                      size_t stride);
+
+gsl_vector_long_double_view
+gsl_vector_complex_long_double_real (gsl_vector_complex_long_double *v);
+
+gsl_vector_long_double_view 
+gsl_vector_complex_long_double_imag (gsl_vector_complex_long_double *v);
+
+gsl_vector_long_double_const_view
+gsl_vector_complex_long_double_const_real (const gsl_vector_complex_long_double *v);
+
+gsl_vector_long_double_const_view 
+gsl_vector_complex_long_double_const_imag (const gsl_vector_complex_long_double *v);
+
+
+/* Operations */
 
 gsl_complex_long_double 
 *gsl_vector_complex_long_double_ptr (const gsl_vector_complex_long_double * v, size_t i);
